@@ -1,7 +1,7 @@
 /*
   This file is part of the kcalcore library.
 
-  Copyright (c) 2010 Klarlvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -34,7 +34,7 @@ void initLocale()
 
 Q_CONSTRUCTOR_FUNCTION(initLocale)
 #endif
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace KCalUtils;
 
 void StringifyTest::testIncidenceStrings()
